@@ -48,6 +48,10 @@ class Plato(flowws.Stage):
             help='Outline for all shapes'),
         Arg('color_scale', None, float, 1, valid_values=flowws.Range(0, 10, True),
             help='Factor to scale color RGB intensities by'),
+        Arg('draw_scale', '-s', float, 1,
+            help='Scale to multiply particle size by'),
+        Arg('display_box', '-b', bool, True,
+            help='Display the system box'),
         Arg('additive_rendering', None, bool, False,
             help='Use additive rendering for shapes'),
         Arg('fast_antialiasing', None, bool, False,
@@ -56,6 +60,8 @@ class Plato(flowws.Stage):
             help='Use Screen Space Ambient Occlusion (SSAO)'),
         Arg('disable_rounding', None, bool, False,
             help='Disable spheropolyhedra and spheropolygons'),
+        Arg('disable_selection', None, bool, False,
+            help='Don\'t allow selection of particles for this scene'),
     ]
 
     def run(self, scope, storage):
@@ -105,6 +111,7 @@ class Plato(flowws.Stage):
         diameters = np.atleast_1d(scope.get('diameter', 1))
         if len(diameters) < N:
             diameters = np.repeat(1, N)
+        diameters = diameters*self.arguments['draw_scale']
 
         if self.arguments.get('disable_rounding', False):
             for description in type_shapes:
@@ -117,7 +124,7 @@ class Plato(flowws.Stage):
             else:
                 type_shapes.append(dict(type='Sphere'))
 
-        primitives = []
+        primitives = list(scope.get('plato_primitives', []))
         for (t, description) in zip(unique_types, type_shapes):
             filt = types == t
 
@@ -141,14 +148,14 @@ class Plato(flowws.Stage):
                 prim.positions = positions[filt, :2]
             else:
                 prim.positions = positions[filt]
-            prim.orientations = orientations[filt]
+            prim.orientations = orientations[filt]*np.sqrt(self.arguments['draw_scale'])
             prim.colors = colors[filt]
             prim.diameters = diameters[filt]
             prim.outline = self.arguments['outline']
 
             primitives.append(prim)
 
-        if 'box' in scope:
+        if 'box' in scope and self.arguments['display_box']:
             prim = draw.Box.from_box(scope['box'])
             prim.width = min(scope['box'][:dimensions])*5e-3
             prim.color = (0, 0, 0, 1)
@@ -169,7 +176,8 @@ class Plato(flowws.Stage):
 
         scope.setdefault('visuals', []).append(self)
         scope.setdefault('visual_link_rotation', []).append(self)
-        scope['selection_visual_target'] = self
+        if not self.arguments['disable_selection']:
+            scope['selection_visual_target'] = self
 
     def draw_plato(self):
         return self.scene
